# Changelog

## v0.5.2 - February 10, 2021

- Added new documenation website (<https://lidar.gishub.org>)
- Improved JOSS paper
- Cleaned up source code

## v0.5.1 - December 12, 2020

## v0.2.0 - September 16, 2018

## v0.1.6 - May 21, 2018

## 0.1.5 - May 16, 2018

## 0.1.3 - May 15, 2018

## 0.1.0 - May 14, 2018
